package com.asset.controller;

import com.asset.common.*;
import com.asset.core.jwt.TokenUtil;
import com.asset.domain.Result;
import com.asset.domain.User;
import com.asset.domain.system.LoginLog;
import com.asset.core.enums.CodeEnum;
import com.asset.service.UserService;
import com.asset.service.system.CertificateService;
import com.asset.service.system.LoginLogService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.io.UnsupportedEncodingException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

/*
 * @author xiaol
 * @date 2020/03/17
 */
@RestController
public class LoginController {

    @Autowired
    UserService userService;

    @Autowired
    CertificateService certificateService;

    @Autowired
    LoginLogService loginLogService;

    @RequestMapping("/login")
    public Result login(@Validated(value={Login.class}) @RequestBody User user, BindingResult result, HttpSession session, HttpServletRequest request, HttpServletResponse response) throws UnsupportedEncodingException, ParseException {
        if (result.hasErrors()) {
            return ResultUtil.Validated(result);
        }
        String mobile= user.getMobile();
        String password= user.getPassword();
        QueryWrapper<User> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("mobile",mobile);
        User admin1 = userService.getOne(queryWrapper);
        if(admin1 == null){  //判断账号是否存在
            return ResultUtil.error(CodeEnum.ISEXITE_NOT_ERROR);
        }else {
            String pass = MD5Util.getEncryption(password);
            String passwordold = admin1.getPassword();
            if (!passwordold.equals(pass)){
                return ResultUtil.error(CodeEnum.LOGIN_ERROR);
            }
        }
        session.setAttribute("mobile",mobile);
        //更新登录时间和ip地址
        //登录成功记录登录日志
        LoginLog loginLog = new LoginLog();
        loginLog.setUser_id(admin1.getId().toString());
        loginLog.setIp(Common.getIpAddress(request));
        loginLog.setLogin_create_at(Common.getDate());
        loginLogService.insertLoginLog(loginLog);
        String token = TokenUtil.sign(mobile);
        System.out.println("-------:" + mobile);
        //登录后写入新的token入库
        User user1 = new User();
        user1.setLoginTime(Common.getDate());
        user1.setToken(token);
        QueryWrapper<User> userQueryWrapper = new QueryWrapper<>();
        userQueryWrapper.eq("id",admin1.getId());
        userService.update(user1,userQueryWrapper);
        return ResultUtil.success(CodeEnum.SUCCESS,token);
    }

    @GetMapping("/loginInfo")
    public Result loginInfo(HttpSession session) {
        String mobile = (String) session.getAttribute("mobile");
        if(mobile != null){
            QueryWrapper<User> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("mobile",mobile);
            User user = userService.getOne(queryWrapper);
            if(user == null){  //判断账号是否存在
                return ResultUtil.error(CodeEnum.ISEXITE_NOT_ERROR);
            }else {
                return ResultUtil.success(CodeEnum.SUCCESS,user);
            }
        }
        return ResultUtil.error(CodeEnum.UN_LOGIN);
    }

    @GetMapping("/loginOut")
    public Result loginOut(HttpSession session) {
        session.invalidate();
        return ResultUtil.success(CodeEnum.SUCCESS);
    }

    @GetMapping("/newToken")
    public Result newToken(HttpServletRequest request) {
        //获取旧的token,并销毁
        String token = request.getHeader("token");
        if(token!=null){
            Object mobile = request.getSession().getAttribute("mobile");;
            QueryWrapper<User> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("mobile",mobile);
            User user = userService.getOne(queryWrapper);
            if(user.getToken().equals(token)){  //比较token是否相等
                String newtoken = TokenUtil.sign(mobile.toString());
                return ResultUtil.success(CodeEnum.SUCCESS,newtoken);
            }
        }
        return ResultUtil.error(CodeEnum.ERROR);
    }

}