package com.asset.controller.admin;

import com.asset.common.*;
import com.asset.domain.Result;
import com.asset.domain.User;
import com.asset.domain.system.*;
import com.asset.service.UserService;
import com.asset.service.system.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.asset.core.enums.CodeEnum;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


/*
 * @author xiaol
 * @date 2020/03/12
 */
@RestController
@RequestMapping(value = "/admin")
public class AdminController {

    @Autowired
    UserService userService;

    @Autowired
    CertificateService certificateService;

    @Autowired
    AreaService areaService;

    @Autowired
    JobService jobService;

    @Autowired
    FailLogService failLogService;

    @Autowired
    FailReasonService failReasonService;

    @Autowired
    //UserMapper userMapper;

    public final static Map<String, String> Expertmap = new HashMap<String, String>();
    static {
        Expertmap.put("1", "省专家库");
        Expertmap.put("2", "市专家库");
    }

    public final String agree = "审核通过";
    public final String refuse = "审核不通过,原因:";

    @RequestMapping(value = "/getUserList")
    public Result getUserList(@RequestParam(defaultValue = "1") int page, @RequestParam(defaultValue = "10") int per, User user) {
        QueryWrapper<User> queryWrapper = new QueryWrapper<>();
        if(user.getState() != null){
            queryWrapper.eq("state",user.getState()).or().eq("name",user.getName()).or().eq("mobile",user.getMobile()).or().eq("email",user.getEmail()).or().eq("employer",user.getEmployer());
        }
         //List list = userService.list(queryWrapper);
        PageHelper.startPage(page, per);
        Map map = Pagination.Pagination(userService.list(queryWrapper));
        return ResultUtil.success(CodeEnum.SUCCESS,map);
    }

    @GetMapping("/getUserById")
    public Result getUserById(int id) {
        QueryWrapper<User> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("id",id);
        User user = userService.getOne(queryWrapper);
        //组合专家凭证
        QueryWrapper<Certificate> certificateWrapper = new QueryWrapper<>();
        certificateWrapper.eq("user_id",user.getId());
        java.util.List<Certificate> list = certificateService.list(certificateWrapper);
        java.util.List listexpert = new ArrayList<>();
        java.util.List listrecom = new ArrayList<>();
        List listother = new ArrayList<>();
        for (Certificate list1 : list) {
            if(list1.getType() == 1){
                listexpert.add(list1.getImage());
            }else if(list1.getType() == 2){
                listrecom.add(list1.getImage());
            }else{
                listother.add(list1.getImage());
            }
        }
        user.setReexpert(listexpert);
        user.setRerecom(listrecom);
        user.setReother(listother);
        user.setExpertType(Expertmap.get(user.getExpertType()));
        //组合地址
        Area p = areaService.getById(user.getProvince());
        user.setProvince(p.getName());
        Area c = areaService.getById(user.getCity());
        user.setCity(c.getName());
        Area co = areaService.getById(user.getCounty());
        user.setCounty(co.getName());
        //专家类型（省级还是市级）
        if(user.getExpertTypeValue().contains(",")){
            String[] arr = user.getExpertTypeValue().split(",");
            String tmp = "";
            for (int i=0;i<arr.length;i++){
                Area pt = areaService.getById(arr[i]);
                tmp += pt.getName();
            }
            user.setExpertTypeValue(tmp);
        }else{
            Area pt = areaService.getById(user.getExpertTypeValue());
            user.setExpertTypeValue(pt.getName());
        }
        //职称
        Job job = jobService.getById(user.getJobId());
        user.setJobId(job.getName());
        //审核历史
        QueryWrapper<FailLog> queryWrapperFail = new QueryWrapper<>();
        queryWrapperFail.eq("user_id",user.getId());
        List<FailLog> fail = failLogService.list(queryWrapperFail);
        user.setFaillog(fail);
        if(user != null){
            return ResultUtil.success(CodeEnum.SUCCESS,user);
        }
        return ResultUtil.success(CodeEnum.ERROR);
    }

    @RequestMapping(value = "/getUserReviewAgree")
    public Result getUserReviewAgree(int id) {
        User user = new User();
        QueryWrapper<User> updateWrapper = new QueryWrapper<>();
        updateWrapper.eq("id",id);
        user.setState(1);
        if(userService.update(user,updateWrapper)){
            //记录审核日志
            FailLog failLog = new FailLog();
            failLog.setUserId(Integer.toString(id));
            failLog.setState(Integer.toString(0));
            failLog.setName(agree);
            failLog.setCreateAt(Common.getDate());
            failLogService.save(failLog);
            return ResultUtil.success(CodeEnum.SUCCESS);
        }else{
            return ResultUtil.success(CodeEnum.ERROR);
        }
    }

    @RequestMapping(value = "/getUserReviewRefuse")
    public Result getUserReviewRefuse(@RequestBody User user) {
        QueryWrapper<User> updateWrapper = new QueryWrapper<>();
        updateWrapper.eq("id",user.getId());
        user.setState(2);
        if(userService.update(user,updateWrapper)){
            //记录审核日志
            FailLog failLog = new FailLog();
            failLog.setUserId(user.getId().toString());
            failLog.setState(Integer.toString(1));
            //拼接失败的原因
            String tmp = "";
            String ref = "";
            String fids = user.getFids();
            String reasons = user.getReason();
            if(fids.contains(",")){
                String[] arr = fids.split(",");
                for (int i=0;i<arr.length;i++){
                    FailReason reason = failReasonService.getById(arr[i]);
                    tmp += reason.getId() +":"+ reason.getName() + ",";
                }
            }else{
                FailReason reason = failReasonService.getById(fids);
                tmp = reason.getId() +":"+ reason.getName();
            }
            if(reasons != null && reasons.length()>0){
                ref = refuse + tmp + reasons;
            }else{
                ref = refuse + tmp;
            }
            failLog.setFid(fids);
            failLog.setName(ref);
            failLog.setCreateAt(Common.getDate());
            failLogService.save(failLog);
            return ResultUtil.success(CodeEnum.SUCCESS);
        }else{
            return ResultUtil.success(CodeEnum.ERROR);
        }
    }

}
