package com.asset.core.filter;

import com.asset.common.Common;
import com.asset.core.jwt.TokenUtil;
import com.asset.domain.User;
import com.asset.service.UserService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;
import com.alibaba.fastjson.JSONObject;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Date;

@Component
public class TokenInterceptor implements HandlerInterceptor {

    @Autowired
    UserService userService;

    @Override
    public boolean preHandle(HttpServletRequest request,
                             HttpServletResponse response,
                             Object handler) throws Exception {
        if (request.getMethod().equals("OPTIONS")) {
            response.setStatus(HttpServletResponse.SC_OK);
            return true;
        }
        response.setCharacterEncoding("utf-8");
        String token = request.getHeader("token");
        if (token != null) {
            // 拦截验证校验token是否正确，并验证token的有效期
            boolean result = TokenUtil.verify(token);
            if (result) {
                System.out.println("通过拦截器");
                return true;
            }
        }
        response.setCharacterEncoding("UTF-8");
        response.setContentType("application/json; charset=utf-8");
        try {
            //JSONObject json = new JSONObject();
            //json.put("msg", "token失效");
            //json.put("code", "10007");
            //response.getWriter().append(json.toJSONString());
            System.out.println("认证失败,未通过拦截器,需重新生成token");
            //判断用户表记录的token的有效期是否过期
            Object mobile = request.getSession().getAttribute("mobile");
            QueryWrapper<User> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("mobile",mobile);
            User user = userService.getOne(queryWrapper);
            //比较数据库里token的refexpire的最长期限
            if(user!=null){
                if(Common.getStringToDate(user.getLoginTime())+Long.valueOf(user.getRefexpire()) > System.currentTimeMillis()){
                    System.out.println("刷新token,生成新的token");
                    token = TokenUtil.sign(mobile.toString());
                    response.setHeader("token",token);
                    //手动调用刷新token接口时就需要下面的更新token代码,自动更新就不需要
                    User user1 = new User();
                    user1.setToken(token);
                    QueryWrapper<User> userQueryWrapper = new QueryWrapper<>();
                    userQueryWrapper.eq("id",user.getId());
                    userService.update(user1,userQueryWrapper);
                    return true;
                }else{      //数据表里的长效期的时间过期了,则要重新登录
                    System.out.println("token超过了最长时效,请重新登录");
                    JSONObject json = new JSONObject();
                    json.put("msg", "token超过了最长时效,请重新登录");
                    json.put("code", "10007");
                    response.getWriter().append(json.toJSONString());
                    return false;
                }
            }
            return false;
        } catch (Exception e) {
            e.printStackTrace();
            response.sendError(500);
            return false;
        }
    }

    @Override
    public void postHandle(HttpServletRequest request,
                           HttpServletResponse response,
                           Object object, ModelAndView mv) throws Exception {
    }

}