package com.asset.core.jwt;

import java.util.Date;
import com.asset.domain.User;
import com.auth0.jwt.JWT;
import com.auth0.jwt.JWTVerifier;
import com.auth0.jwt.algorithms.Algorithm;
import com.auth0.jwt.interfaces.DecodedJWT;

public class TokenUtil {
    //过期时间(10小时)
    private static final long EXPIRE_TIME = 1 * 60 * 60 * 1000;

    //使用静态的字符密文或者key来获取算法器，token秘钥，请勿泄露，请勿随便修改
    private static final String TOKEN_SECRET = "expert";  //密钥盐

    /**
     * 签名生成
     * @param mobile
     * @return
     */
    public static String sign(String mobile) {
        String token = null;
        try {
            Date expiresAt = new Date(System.currentTimeMillis() + EXPIRE_TIME);
            token = JWT.create()
                    .withIssuer("auth0")
                    .withClaim("mobile", mobile)
                    .withExpiresAt(expiresAt)
                    // 使用了HMAC256加密算法。
                    .sign(Algorithm.HMAC256(TOKEN_SECRET));
            System.out.println(token);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return token;
    }

    /**
     * 签名验证
     * @param token
     * @return
     */
    public static boolean verify(String token) {
        try {
            JWTVerifier verifier = JWT.require(Algorithm.HMAC256(TOKEN_SECRET)).withIssuer("auth0").build();
            DecodedJWT jwt = verifier.verify(token);
            System.out.println("认证通过：");
            System.out.println("mobile:" + jwt.getClaim("mobile").asString());
            System.out.println("过期时间：" + jwt.getExpiresAt());
            return true;
        } catch (Exception e) {
            return false;
        }
    }
}