package com.asset.domain;

import com.alibaba.fastjson.annotation.JSONField;
import com.asset.common.Insert;
import com.asset.common.Login;
import com.asset.common.Special;
import com.asset.common.Update;
import com.asset.domain.system.Certificate;
import com.asset.domain.system.LoginLog;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;
import lombok.experimental.Accessors;
import javax.validation.constraints.Email;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;
import java.io.Serializable;
import java.util.Date;
import java.util.List;

/*
 * @author xiaol
 * @date 2020/03/10
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@TableName("ex_user")
@ToString
public class User implements Serializable {

    private Integer id;
    /**
     * 姓名
     */
    @NotEmpty(message = "{name.NotEmpty}", groups = {Insert.class})
    private String name;
    /**
     * 密码
     */
    @NotEmpty(message = "{password.NotEmpty}", groups = {Insert.class,Special.class,Login.class})
    @Pattern(regexp="^[a-zA-Z0-9]+$",message="{password.Pattern}",groups = {Insert.class,Special.class,Login.class})
    @Size(min=6,max=20,message="{password.size}",groups = {Insert.class,Special.class,Login.class})
    private String password;

    @NotEmpty(message = "{sex.NotEmpty}", groups = {Insert.class,Update.class})
    private String sex;

    @NotEmpty(message = "{mobile.NotEmpty}", groups = {Insert.class,Update.class,Login.class})
    @Pattern(regexp = "1[3|4|5|7|8][0-9]\\d{8}",message = "{mobile.Pattern}", groups = {Insert.class,Update.class})
    private String mobile;

    @NotEmpty(message = "{email.NotEmpty}", groups = {Insert.class,Update.class})
    @Email(message="{email.Pattern}",groups = {Insert.class,Update.class})
    private String email;

    private Integer state;

    @NotEmpty(message = "{province.NotEmpty}", groups = {Insert.class,Update.class})
    private String province;

    private String createAt;

    @NotEmpty(message = "{card_front.NotEmpty}", groups = {Insert.class,Update.class})
    private String cardFront;

    @NotEmpty(message = "{card_obverse.NotEmpty}", groups = {Insert.class,Update.class})
    private String cardObverse;

    @NotEmpty(message = "{school.NotEmpty}", groups = {Insert.class,Update.class})
    private String school;

    private String discipline;

    @NotEmpty(message = "{job_id.NotEmpty}", groups = {Insert.class,Update.class})
    private String jobId;

    private String employer;

    @NotEmpty(message = "{city.NotEmpty}", groups = {Insert.class,Update.class})
    private String city;

    @NotEmpty(message = "{county.NotEmpty}", groups = {Insert.class,Update.class})
    private String county;

    @NotEmpty(message = "{address.NotEmpty}", groups = {Insert.class,Update.class})
    private String address;

    private String isExpert;

    private String expertType;

    private String expertTypeValue;

    @TableField(exist = false)
    private String expert;  //专家凭证(入库用)

    @TableField(exist = false)
    private String recom;   //推荐凭证(入库用)

    @TableField(exist = false)
    private String other;   //其他凭证(入库用)

    @TableField(exist = false)
    private List reexpert;  //专家凭证(展示)

    @TableField(exist = false)
    private List rerecom;   //推荐凭证(展示)

    @TableField(exist = false)
    private List reother;   //其他凭证(展示)

    private String expertRange;

    @JsonFormat(pattern = "yyyy-MM-dd")
    private String loginTime;

    //@JsonFormat(pattern = "yyyy-MM-dd", timezone="GMT+8")
    //private Date yy;

    private String ip;

    @TableField(exist = false)
    private List faillog;

    @TableField(exist = false)
    private String fids;

    @TableField(exist = false)
    private String reason;

    private String token;

    private String refexpire;

}
